@@ -1,7 +1,4 @@
-import pprint
-import math
-import sys
-
+import numpy
 
 def generate():
     """
@@ -10,12 +7,13 @@ def generate():
     """
 
     # C0
-    base = [15.892725498, 16.351597831, 16.837756133]
+    base = [7.946362749, 8.1757989155, 8.4188780665]
+    
     # 12th root of 2
-    multiplier = 1.05946309436
+    multiplier = numpy.float_power(2.0, 1.0 / 12)
 
     notes = {0: base}
-    for i in range(1, 256):
+    for i in range(1, 128):
         mid = multiplier * notes[i - 1][1]
         low = (mid + notes[i - 1][1]) / 2.0
         high = (mid + (multiplier * mid)) / 2.0
